@@ -10,6 +10,13 @@ from .base import (
 )
 from .. import exceptions
 
+__all__ = [
+    "FullQueueNameMixin",
+    "RedisClientTaskCourier",
+    "RedisWorkerTaskCourier",
+    "RedisClientWorkerTaskCourier",
+]
+
 
 class FullQueueNameMixin:
     """
@@ -44,15 +51,18 @@ class RedisClientTaskCourier(FullQueueNameMixin, BaseClientTaskCourier):
     def __init__(self, redis_connection):
         self.redis_connection = redis_connection
 
+    def _generate_task_id(self):
+        return uuid.uuid1()
+
     def get_task_result(
             self, queue_name, task_id, delete_data=True):
         """Returns task retuls, if it exists.
         Otherwise, raises exceptions.TaskResultDoesNotExist
         Client side method.
 
-        * queue_name - queue name, used in the add_task_to_queue method.
-        * task_id - id of the task that the add_task_to_queue method returned.
-        * delete_data - Whether to remove data from the queue after retrieving.
+        - queue_name - queue name, used in the add_task_to_queue method.
+        - task_id - id of the task that the add_task_to_queue method returned.
+        - delete_data - Whether to remove data from the queue after retrieving.
           default is True."""
 
         name = self._get_full_queue_name(queue_name, "results:") + str(task_id)
@@ -71,20 +81,22 @@ class RedisClientTaskCourier(FullQueueNameMixin, BaseClientTaskCourier):
         a result availability. Raises TimeoutError in case of timeout.
         Client side method.
 
-        * queue_name - queue name, used in the add_task_to_queue method.
-        * task_id - id of the task that the add_task_to_queue method returned.
-        * delete_data - Whether to remove data from the queue after retrieving.
+        - queue_name - queue name, used in the add_task_to_queue method.
+        - task_id - id of the task that the add_task_to_queue method returned.
+        - delete_data - Whether to remove data from the queue after retrieving.
           default is True.
-        * timeout - timeout to wait for the result in seconds or as an
+        - timeout - timeout to wait for the result in seconds or as an
           datetime.timedelta object. Default is None (wait indefinitely until
           it appears). If specified - raises TimeoutError if time is up"""
 
         utc_start_time = datetime.datetime.utcnow()
         if isinstance(timeout, int) or isinstance(timeout, float):
             timeout = datetime.timedelta(seconds=timeout)
-        while not timeout or \
+        first_iteration = True
+        while first_iteration or not timeout or \
                 utc_start_time + timeout > datetime.datetime.utcnow():
             try:
+                first_iteration = False
                 return self.get_task_result(
                     queue_name=queue_name,
                     task_id=task_id,
@@ -97,10 +109,10 @@ class RedisClientTaskCourier(FullQueueNameMixin, BaseClientTaskCourier):
         """Adds a task to the redis queue for processing. Returns task_id.
         Client side method.
 
-        * queue_name - queue name, used in the add_task_to_queue method.
-        * task_data - task objects, what will be added to redis qeueue."""
+        - queue_name - queue name, used in the add_task_to_queue method.
+        - task_data - task objects, what will be added to redis qeueue."""
 
-        task_id = uuid.uuid1()
+        task_id = self._generate_task_id()
         task = pickle.dumps((task_id, task_data))
         self.redis_connection.rpush(
             self._get_full_queue_name(queue_name=queue_name, sufix="pending"),
@@ -132,8 +144,8 @@ class RedisWorkerTaskCourier(FullQueueNameMixin, BaseWorkerTaskCourier):
         Task is tuple of (task_id, task_data). The result like
         [(task_id, task_data), (task_id, task_data), ...].
 
-        * queue_name - queue name, used in the add_task_to_queue method.
-        * max_count - the maximum number of tasks that can be extracted from
+        - queue_name - queue name, used in the add_task_to_queue method.
+        - max_count - the maximum number of tasks that can be extracted from
           the queue"""
 
         tasks = self.redis_connection.lpop(
@@ -148,7 +160,7 @@ class RedisWorkerTaskCourier(FullQueueNameMixin, BaseWorkerTaskCourier):
         If task doesn't exists, raises exceptions.TaskDoesNotExist.
         Worker side method.
 
-        * queue_name - queue name, used in the add_task_to_queue method."""
+        - queue_name - queue name, used in the add_task_to_queue method."""
 
         task = self.redis_connection.lpop(
             self._get_full_queue_name(queue_name, "pending")
@@ -164,8 +176,8 @@ class RedisWorkerTaskCourier(FullQueueNameMixin, BaseWorkerTaskCourier):
         Raises TimeoutError in case of timeout.
         Worker side method.
 
-        * queue_name - queue name, used in the add_task_to_queue method.
-        * timeout - timeout to wait for the task in seconds. Default is None
+        - queue_name - queue name, used in the add_task_to_queue method.
+        - timeout - timeout to wait for the task in seconds. Default is None
           (Waiting forever until it appears). If specified - raised
           TimeoutError if time is up"""
 
@@ -181,9 +193,9 @@ class RedisWorkerTaskCourier(FullQueueNameMixin, BaseWorkerTaskCourier):
         """Return the result of processing the task to the client via redis.
         Worker side method.
 
-        * queue_name - queue name, used in the add_task_to_queue method.
-        * task_id - id of the task.
-        * task_data - task objects, what will be returned to the client."""
+        - queue_name - queue name, used in the add_task_to_queue method.
+        - task_id - id of the task.
+        - task_data - task objects, what will be returned to the client."""
 
         name = self._get_full_queue_name(
             queue_name=queue_name, sufix="results:") + str(task_id)
